Puchikarui
==========

A minimalist SQLite wrapper library for Python 3 which supports ORM features.
It is available on PyPI and can be installed using `pip`.

```bash
pip install puchikarui
# or with python -m pip
python -m pip install puchikarui
python3 -m pip install puchikarui
```

To run demo, please try this script:
```bash
python3 puchikarui.demo.py
```

# Why puchikarui
`Puchikarui` is *NOT* an ORM library.
If you want ORM features, please consider https://github.com/coleifer/peewee or https://www.sqlalchemy.org/.
Puchikarui is a helper library which provides helper functions to work with SQLite database directly (less magic and more control).
